Newson Krum testdata
====================

Files will be downloaded from https://www.microsoft.com/en-us/research/publication/hidden-markov-map-matching-noise-sparseness/

- `gps_data.txt`
- `road_network.txt`
- `ground_truth_route.txt`


